Class: MassPayRubySdk::SpendBackTxn

Inherits:
Object
  • Object
show all
Defined in:
lib/masspay_ruby_sdk/models/spend_back_txn.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SpendBackTxn

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/masspay_ruby_sdk/models/spend_back_txn.rb', line 72

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `MassPayRubySdk::SpendBackTxn` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `MassPayRubySdk::SpendBackTxn`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'client_spendback_id')
    self.client_spendback_id = attributes[:'client_spendback_id']
  end

  if attributes.key?(:'source_token')
    self.source_token = attributes[:'source_token']
  end

  if attributes.key?(:'source_currency_code')
    self.source_currency_code = attributes[:'source_currency_code']
  else
    self.source_currency_code = 'USD'
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'notes')
    self.notes = attributes[:'notes']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end
end

Instance Attribute Details

#amountObject

The amount to debit the user’s wallet in source currency



27
28
29
# File 'lib/masspay_ruby_sdk/models/spend_back_txn.rb', line 27

def amount
  @amount
end

#client_spendback_idObject

A client defined spend back identifier. This is the unique ID assigned to the load on your system. Max 50 characters.



18
19
20
# File 'lib/masspay_ruby_sdk/models/spend_back_txn.rb', line 18

def client_spendback_id
  @client_spendback_id
end

#metadataObject

Optional JSON object with attributes that can later be searched to locate this spendback. Do not include PII as this object is not encrypted.



33
34
35
# File 'lib/masspay_ruby_sdk/models/spend_back_txn.rb', line 33

def 
  
end

#notesObject

A description for the spend back



30
31
32
# File 'lib/masspay_ruby_sdk/models/spend_back_txn.rb', line 30

def notes
  @notes
end

#source_currency_codeObject

The currency originating balance is stored in. Using [ISO 4217](en.wikipedia.org/wiki/ISO_4217) format. In most cases this value will be USD, and therefore the defaut value if none is provided



24
25
26
# File 'lib/masspay_ruby_sdk/models/spend_back_txn.rb', line 24

def source_currency_code
  @source_currency_code
end

#source_tokenObject

Token that represents the funding source i.e. bank account, wallet. 36 characters long



21
22
23
# File 'lib/masspay_ruby_sdk/models/spend_back_txn.rb', line 21

def source_token
  @source_token
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



48
49
50
# File 'lib/masspay_ruby_sdk/models/spend_back_txn.rb', line 48

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
# File 'lib/masspay_ruby_sdk/models/spend_back_txn.rb', line 36

def self.attribute_map
  {
    :'client_spendback_id' => :'client_spendback_id',
    :'source_token' => :'source_token',
    :'source_currency_code' => :'source_currency_code',
    :'amount' => :'amount',
    :'notes' => :'notes',
    :'metadata' => :'metadata'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



207
208
209
# File 'lib/masspay_ruby_sdk/models/spend_back_txn.rb', line 207

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
# File 'lib/masspay_ruby_sdk/models/spend_back_txn.rb', line 65

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
# File 'lib/masspay_ruby_sdk/models/spend_back_txn.rb', line 53

def self.openapi_types
  {
    :'client_spendback_id' => :'String',
    :'source_token' => :'String',
    :'source_currency_code' => :'String',
    :'amount' => :'Float',
    :'notes' => :'String',
    :'metadata' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



181
182
183
184
185
186
187
188
189
190
# File 'lib/masspay_ruby_sdk/models/spend_back_txn.rb', line 181

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      client_spendback_id == o.client_spendback_id &&
      source_token == o.source_token &&
      source_currency_code == o.source_currency_code &&
      amount == o.amount &&
      notes == o.notes &&
       == o.
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/masspay_ruby_sdk/models/spend_back_txn.rb', line 238

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = MassPayRubySdk.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/masspay_ruby_sdk/models/spend_back_txn.rb', line 309

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/masspay_ruby_sdk/models/spend_back_txn.rb', line 214

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


194
195
196
# File 'lib/masspay_ruby_sdk/models/spend_back_txn.rb', line 194

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



200
201
202
# File 'lib/masspay_ruby_sdk/models/spend_back_txn.rb', line 200

def hash
  [client_spendback_id, source_token, source_currency_code, amount, notes, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/masspay_ruby_sdk/models/spend_back_txn.rb', line 114

def list_invalid_properties
  invalid_properties = Array.new
  if @client_spendback_id.nil?
    invalid_properties.push('invalid value for "client_spendback_id", client_spendback_id cannot be nil.')
  end

  if @client_spendback_id.to_s.length > 50
    invalid_properties.push('invalid value for "client_spendback_id", the character length must be smaller than or equal to 50.')
  end

  if @source_token.nil?
    invalid_properties.push('invalid value for "source_token", source_token cannot be nil.')
  end

  if @source_currency_code.nil?
    invalid_properties.push('invalid value for "source_currency_code", source_currency_code cannot be nil.')
  end

  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if !@notes.nil? && @notes.to_s.length > 255
    invalid_properties.push('invalid value for "notes", the character length must be smaller than or equal to 255.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



285
286
287
# File 'lib/masspay_ruby_sdk/models/spend_back_txn.rb', line 285

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/masspay_ruby_sdk/models/spend_back_txn.rb', line 291

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



279
280
281
# File 'lib/masspay_ruby_sdk/models/spend_back_txn.rb', line 279

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



145
146
147
148
149
150
151
152
153
# File 'lib/masspay_ruby_sdk/models/spend_back_txn.rb', line 145

def valid?
  return false if @client_spendback_id.nil?
  return false if @client_spendback_id.to_s.length > 50
  return false if @source_token.nil?
  return false if @source_currency_code.nil?
  return false if @amount.nil?
  return false if !@notes.nil? && @notes.to_s.length > 255
  true
end