Class: MassPayRubySdk::SpendBacks

Inherits:
Object
  • Object
show all
Defined in:
lib/masspay_ruby_sdk/models/spend_backs.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SpendBacks

Initializes the object



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/masspay_ruby_sdk/models/spend_backs.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `MassPayRubySdk::SpendBacks` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `MassPayRubySdk::SpendBacks`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'spendback_token')
    self.spendback_token = attributes[:'spendback_token']
  end

  if attributes.key?(:'time_of_spendback')
    self.time_of_spendback = attributes[:'time_of_spendback']
  end

  if attributes.key?(:'client_spendback_id')
    self.client_spendback_id = attributes[:'client_spendback_id']
  end

  if attributes.key?(:'source_token')
    self.source_token = attributes[:'source_token']
  end

  if attributes.key?(:'wallet_token')
    self.wallet_token = attributes[:'wallet_token']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'source_currency_code')
    self.source_currency_code = attributes[:'source_currency_code']
  end

  if attributes.key?(:'notes')
    self.notes = attributes[:'notes']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end
end

Instance Attribute Details

#amountObject

The amount to credit the user’s wallet in source currency



34
35
36
# File 'lib/masspay_ruby_sdk/models/spend_backs.rb', line 34

def amount
  @amount
end

#client_spendback_idObject

A client defined spend back identifier. This is the unique ID assigned to the spend back on your system. Max 50 characters.



25
26
27
# File 'lib/masspay_ruby_sdk/models/spend_backs.rb', line 25

def client_spendback_id
  @client_spendback_id
end

#metadataObject

Optional JSON object with attributes that can later be searched to locate this spendback. Do not include PII as this object is not encrypted.



43
44
45
# File 'lib/masspay_ruby_sdk/models/spend_backs.rb', line 43

def 
  @metadata
end

#notesObject

A description for the load. Will be visible to the user receiving the load



40
41
42
# File 'lib/masspay_ruby_sdk/models/spend_backs.rb', line 40

def notes
  @notes
end

#source_currency_codeObject

The currency originating balance is stored in. Using [ISO 4217](en.wikipedia.org/wiki/ISO_4217) format. In most cases this value will be USD, and therefore the defaut value if none is provided



37
38
39
# File 'lib/masspay_ruby_sdk/models/spend_backs.rb', line 37

def source_currency_code
  @source_currency_code
end

#source_tokenObject

Token that represents the funding source i.e. bank account, wallet. 36 characters long



28
29
30
# File 'lib/masspay_ruby_sdk/models/spend_backs.rb', line 28

def source_token
  @source_token
end

#spendback_tokenObject

Token representing the load token



19
20
21
# File 'lib/masspay_ruby_sdk/models/spend_backs.rb', line 19

def spendback_token
  @spendback_token
end

#time_of_spendbackObject

The timestamp the spend back was created in the system. Using UTC timestamp.[ISO 8601](en.wikipedia.org/wiki/ISO_8601)



22
23
24
# File 'lib/masspay_ruby_sdk/models/spend_backs.rb', line 22

def time_of_spendback
  @time_of_spendback
end

#wallet_tokenObject

Token that represents the wallet that received the funds. 36 characters long



31
32
33
# File 'lib/masspay_ruby_sdk/models/spend_backs.rb', line 31

def wallet_token
  @wallet_token
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



61
62
63
# File 'lib/masspay_ruby_sdk/models/spend_backs.rb', line 61

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/masspay_ruby_sdk/models/spend_backs.rb', line 46

def self.attribute_map
  {
    :'spendback_token' => :'spendback_token',
    :'time_of_spendback' => :'time_of_spendback',
    :'client_spendback_id' => :'client_spendback_id',
    :'source_token' => :'source_token',
    :'wallet_token' => :'wallet_token',
    :'amount' => :'amount',
    :'source_currency_code' => :'source_currency_code',
    :'notes' => :'notes',
    :'metadata' => :'metadata'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



222
223
224
# File 'lib/masspay_ruby_sdk/models/spend_backs.rb', line 222

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/masspay_ruby_sdk/models/spend_backs.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/masspay_ruby_sdk/models/spend_backs.rb', line 66

def self.openapi_types
  {
    :'spendback_token' => :'String',
    :'time_of_spendback' => :'String',
    :'client_spendback_id' => :'String',
    :'source_token' => :'String',
    :'wallet_token' => :'String',
    :'amount' => :'Float',
    :'source_currency_code' => :'String',
    :'notes' => :'String',
    :'metadata' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/masspay_ruby_sdk/models/spend_backs.rb', line 193

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      spendback_token == o.spendback_token &&
      time_of_spendback == o.time_of_spendback &&
      client_spendback_id == o.client_spendback_id &&
      source_token == o.source_token &&
      wallet_token == o.wallet_token &&
      amount == o.amount &&
      source_currency_code == o.source_currency_code &&
      notes == o.notes &&
       == o.
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/masspay_ruby_sdk/models/spend_backs.rb', line 253

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = MassPayRubySdk.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/masspay_ruby_sdk/models/spend_backs.rb', line 324

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/masspay_ruby_sdk/models/spend_backs.rb', line 229

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


209
210
211
# File 'lib/masspay_ruby_sdk/models/spend_backs.rb', line 209

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



215
216
217
# File 'lib/masspay_ruby_sdk/models/spend_backs.rb', line 215

def hash
  [spendback_token, time_of_spendback, client_spendback_id, source_token, wallet_token, amount, source_currency_code, notes, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/masspay_ruby_sdk/models/spend_backs.rb', line 140

def list_invalid_properties
  invalid_properties = Array.new
  if @spendback_token.nil?
    invalid_properties.push('invalid value for "spendback_token", spendback_token cannot be nil.')
  end

  if @time_of_spendback.nil?
    invalid_properties.push('invalid value for "time_of_spendback", time_of_spendback cannot be nil.')
  end

  if @client_spendback_id.nil?
    invalid_properties.push('invalid value for "client_spendback_id", client_spendback_id cannot be nil.')
  end

  if @source_token.nil?
    invalid_properties.push('invalid value for "source_token", source_token cannot be nil.')
  end

  if @wallet_token.nil?
    invalid_properties.push('invalid value for "wallet_token", wallet_token cannot be nil.')
  end

  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @source_currency_code.nil?
    invalid_properties.push('invalid value for "source_currency_code", source_currency_code cannot be nil.')
  end

  if @notes.nil?
    invalid_properties.push('invalid value for "notes", notes cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



300
301
302
# File 'lib/masspay_ruby_sdk/models/spend_backs.rb', line 300

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/masspay_ruby_sdk/models/spend_backs.rb', line 306

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



294
295
296
# File 'lib/masspay_ruby_sdk/models/spend_backs.rb', line 294

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



179
180
181
182
183
184
185
186
187
188
189
# File 'lib/masspay_ruby_sdk/models/spend_backs.rb', line 179

def valid?
  return false if @spendback_token.nil?
  return false if @time_of_spendback.nil?
  return false if @client_spendback_id.nil?
  return false if @source_token.nil?
  return false if @wallet_token.nil?
  return false if @amount.nil?
  return false if @source_currency_code.nil?
  return false if @notes.nil?
  true
end