Class: MassPayRubySdk::TaxYearUserResp
- Inherits:
-
Object
- Object
- MassPayRubySdk::TaxYearUserResp
- Defined in:
- lib/masspay_ruby_sdk/models/tax_year_user_resp.rb
Instance Attribute Summary collapse
-
#address1 ⇒ Object
Returns the value of attribute address1.
-
#address2 ⇒ Object
Returns the value of attribute address2.
-
#balance ⇒ Object
Returns the value of attribute balance.
-
#business_name ⇒ Object
Returns the value of attribute business_name.
-
#city ⇒ Object
Returns the value of attribute city.
-
#country ⇒ Object
Returns the value of attribute country.
-
#date_of_birth ⇒ Object
Returns the value of attribute date_of_birth.
-
#email ⇒ Object
Returns the value of attribute email.
-
#first_name ⇒ Object
Returns the value of attribute first_name.
-
#last_name ⇒ Object
Returns the value of attribute last_name.
-
#middle_name ⇒ Object
Returns the value of attribute middle_name.
-
#mobile_number ⇒ Object
Returns the value of attribute mobile_number.
-
#postal_code ⇒ Object
Returns the value of attribute postal_code.
-
#state_province ⇒ Object
Returns the value of attribute state_province.
-
#tax_id ⇒ Object
Returns the value of attribute tax_id.
-
#user_token ⇒ Object
Returns the value of attribute user_token.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TaxYearUserResp
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ TaxYearUserResp
Initializes the object
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 106 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `MassPayRubySdk::TaxYearUserResp` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `MassPayRubySdk::TaxYearUserResp`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'user_token') self.user_token = attributes[:'user_token'] end if attributes.key?(:'address1') self.address1 = attributes[:'address1'] end if attributes.key?(:'address2') self.address2 = attributes[:'address2'] end if attributes.key?(:'city') self.city = attributes[:'city'] end if attributes.key?(:'state_province') self.state_province = attributes[:'state_province'] end if attributes.key?(:'postal_code') self.postal_code = attributes[:'postal_code'] end if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'first_name') self.first_name = attributes[:'first_name'] end if attributes.key?(:'middle_name') self.middle_name = attributes[:'middle_name'] end if attributes.key?(:'last_name') self.last_name = attributes[:'last_name'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'mobile_number') self.mobile_number = attributes[:'mobile_number'] end if attributes.key?(:'business_name') self.business_name = attributes[:'business_name'] end if attributes.key?(:'date_of_birth') self.date_of_birth = attributes[:'date_of_birth'] end if attributes.key?(:'balance') self.balance = attributes[:'balance'] end if attributes.key?(:'tax_id') self.tax_id = attributes[:'tax_id'] end end |
Instance Attribute Details
#address1 ⇒ Object
Returns the value of attribute address1.
19 20 21 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 19 def address1 @address1 end |
#address2 ⇒ Object
Returns the value of attribute address2.
21 22 23 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 21 def address2 @address2 end |
#balance ⇒ Object
Returns the value of attribute balance.
45 46 47 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 45 def balance @balance end |
#business_name ⇒ Object
Returns the value of attribute business_name.
41 42 43 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 41 def business_name @business_name end |
#city ⇒ Object
Returns the value of attribute city.
23 24 25 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 23 def city @city end |
#country ⇒ Object
Returns the value of attribute country.
29 30 31 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 29 def country @country end |
#date_of_birth ⇒ Object
Returns the value of attribute date_of_birth.
43 44 45 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 43 def date_of_birth @date_of_birth end |
#email ⇒ Object
Returns the value of attribute email.
37 38 39 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 37 def email @email end |
#first_name ⇒ Object
Returns the value of attribute first_name.
31 32 33 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 31 def first_name @first_name end |
#last_name ⇒ Object
Returns the value of attribute last_name.
35 36 37 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 35 def last_name @last_name end |
#middle_name ⇒ Object
Returns the value of attribute middle_name.
33 34 35 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 33 def middle_name @middle_name end |
#mobile_number ⇒ Object
Returns the value of attribute mobile_number.
39 40 41 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 39 def mobile_number @mobile_number end |
#postal_code ⇒ Object
Returns the value of attribute postal_code.
27 28 29 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 27 def postal_code @postal_code end |
#state_province ⇒ Object
Returns the value of attribute state_province.
25 26 27 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 25 def state_province @state_province end |
#tax_id ⇒ Object
Returns the value of attribute tax_id.
47 48 49 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 47 def tax_id @tax_id end |
#user_token ⇒ Object
Returns the value of attribute user_token.
17 18 19 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 17 def user_token @user_token end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
72 73 74 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 72 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 50 def self.attribute_map { :'user_token' => :'user_token', :'address1' => :'address1', :'address2' => :'address2', :'city' => :'city', :'state_province' => :'state_province', :'postal_code' => :'postal_code', :'country' => :'country', :'first_name' => :'first_name', :'middle_name' => :'middle_name', :'last_name' => :'last_name', :'email' => :'email', :'mobile_number' => :'mobile_number', :'business_name' => :'business_name', :'date_of_birth' => :'date_of_birth', :'balance' => :'balance', :'tax_id' => :'tax_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
270 271 272 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 270 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
99 100 101 102 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 99 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 77 def self.openapi_types { :'user_token' => :'String', :'address1' => :'String', :'address2' => :'String', :'city' => :'String', :'state_province' => :'String', :'postal_code' => :'String', :'country' => :'String', :'first_name' => :'String', :'middle_name' => :'String', :'last_name' => :'String', :'email' => :'String', :'mobile_number' => :'String', :'business_name' => :'String', :'date_of_birth' => :'String', :'balance' => :'Float', :'tax_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 234 def ==(o) return true if self.equal?(o) self.class == o.class && user_token == o.user_token && address1 == o.address1 && address2 == o.address2 && city == o.city && state_province == o.state_province && postal_code == o.postal_code && country == o.country && first_name == o.first_name && middle_name == o.middle_name && last_name == o.last_name && email == o.email && mobile_number == o.mobile_number && business_name == o.business_name && date_of_birth == o.date_of_birth && balance == o.balance && tax_id == o.tax_id end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 301 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = MassPayRubySdk.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 372 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 277 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
257 258 259 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 257 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
263 264 265 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 263 def hash [user_token, address1, address2, city, state_province, postal_code, country, first_name, middle_name, last_name, email, mobile_number, business_name, date_of_birth, balance, tax_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 186 def list_invalid_properties invalid_properties = Array.new if @address1.nil? invalid_properties.push('invalid value for "address1", address1 cannot be nil.') end if @city.nil? invalid_properties.push('invalid value for "city", city cannot be nil.') end if @country.nil? invalid_properties.push('invalid value for "country", country cannot be nil.') end if @first_name.nil? invalid_properties.push('invalid value for "first_name", first_name cannot be nil.') end if @last_name.nil? invalid_properties.push('invalid value for "last_name", last_name cannot be nil.') end if @date_of_birth.nil? invalid_properties.push('invalid value for "date_of_birth", date_of_birth cannot be nil.') end if @balance.nil? invalid_properties.push('invalid value for "balance", balance cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
348 349 350 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 348 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 354 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
342 343 344 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 342 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
221 222 223 224 225 226 227 228 229 230 |
# File 'lib/masspay_ruby_sdk/models/tax_year_user_resp.rb', line 221 def valid? return false if @address1.nil? return false if @city.nil? return false if @country.nil? return false if @first_name.nil? return false if @last_name.nil? return false if @date_of_birth.nil? return false if @balance.nil? true end |