Class: MassPayRubySdk::Loads
- Inherits:
-
Object
- Object
- MassPayRubySdk::Loads
- Defined in:
- lib/masspay_ruby_sdk/models/loads.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount to credit the user’s wallet in source currency.
-
#client_load_id ⇒ Object
A client defined load identifier.
-
#load_token ⇒ Object
Token representing the load token.
-
#metadata ⇒ Object
Optional JSON object with attributes that can later be searched to locate this load.
-
#notes ⇒ Object
A description for the load.
-
#source_currency_code ⇒ Object
The currency originating balance is stored in.
-
#source_token ⇒ Object
Token that represents the funding source i.e.
-
#status ⇒ Object
Status of the load.
-
#time_of_load ⇒ Object
The timestamp the load was processed.
-
#wallet_token ⇒ Object
Token that represents the wallet that received the funds.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Loads
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Loads
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/masspay_ruby_sdk/models/loads.rb', line 114 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `MassPayRubySdk::Loads` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `MassPayRubySdk::Loads`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'load_token') self.load_token = attributes[:'load_token'] end if attributes.key?(:'time_of_load') self.time_of_load = attributes[:'time_of_load'] end if attributes.key?(:'client_load_id') self.client_load_id = attributes[:'client_load_id'] end if attributes.key?(:'source_token') self.source_token = attributes[:'source_token'] end if attributes.key?(:'wallet_token') self.wallet_token = attributes[:'wallet_token'] end if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'source_currency_code') self.source_currency_code = attributes[:'source_currency_code'] end if attributes.key?(:'notes') self.notes = attributes[:'notes'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end end |
Instance Attribute Details
#amount ⇒ Object
The amount to credit the user’s wallet in source currency
33 34 35 |
# File 'lib/masspay_ruby_sdk/models/loads.rb', line 33 def amount @amount end |
#client_load_id ⇒ Object
A client defined load identifier. This is the unique ID assigned to the load on your system. Max 50 characters.
24 25 26 |
# File 'lib/masspay_ruby_sdk/models/loads.rb', line 24 def client_load_id @client_load_id end |
#load_token ⇒ Object
Token representing the load token
18 19 20 |
# File 'lib/masspay_ruby_sdk/models/loads.rb', line 18 def load_token @load_token end |
#metadata ⇒ Object
Optional JSON object with attributes that can later be searched to locate this load. Do not include PII as this object is not encrypted.
45 46 47 |
# File 'lib/masspay_ruby_sdk/models/loads.rb', line 45 def @metadata end |
#notes ⇒ Object
A description for the load. Will be visible to the user receiving the load
39 40 41 |
# File 'lib/masspay_ruby_sdk/models/loads.rb', line 39 def notes @notes end |
#source_currency_code ⇒ Object
The currency originating balance is stored in. Using [ISO 4217](en.wikipedia.org/wiki/ISO_4217) format. In most cases this value will be USD, and therefore the defaut value if none is provided
36 37 38 |
# File 'lib/masspay_ruby_sdk/models/loads.rb', line 36 def source_currency_code @source_currency_code end |
#source_token ⇒ Object
Token that represents the funding source i.e. bank account, wallet. 36 characters long
27 28 29 |
# File 'lib/masspay_ruby_sdk/models/loads.rb', line 27 def source_token @source_token end |
#status ⇒ Object
Status of the load
42 43 44 |
# File 'lib/masspay_ruby_sdk/models/loads.rb', line 42 def status @status end |
#time_of_load ⇒ Object
The timestamp the load was processed. If not processed yet, a future date will be returned. Using UTC timestamp.[ISO 8601](en.wikipedia.org/wiki/ISO_8601)
21 22 23 |
# File 'lib/masspay_ruby_sdk/models/loads.rb', line 21 def time_of_load @time_of_load end |
#wallet_token ⇒ Object
Token that represents the wallet that received the funds. 36 characters long
30 31 32 |
# File 'lib/masspay_ruby_sdk/models/loads.rb', line 30 def wallet_token @wallet_token end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
86 87 88 |
# File 'lib/masspay_ruby_sdk/models/loads.rb', line 86 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/masspay_ruby_sdk/models/loads.rb', line 70 def self.attribute_map { :'load_token' => :'load_token', :'time_of_load' => :'time_of_load', :'client_load_id' => :'client_load_id', :'source_token' => :'source_token', :'wallet_token' => :'wallet_token', :'amount' => :'amount', :'source_currency_code' => :'source_currency_code', :'notes' => :'notes', :'status' => :'status', :'metadata' => :'metadata' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
270 271 272 |
# File 'lib/masspay_ruby_sdk/models/loads.rb', line 270 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
107 108 109 110 |
# File 'lib/masspay_ruby_sdk/models/loads.rb', line 107 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/masspay_ruby_sdk/models/loads.rb', line 91 def self.openapi_types { :'load_token' => :'String', :'time_of_load' => :'String', :'client_load_id' => :'String', :'source_token' => :'String', :'wallet_token' => :'String', :'amount' => :'Float', :'source_currency_code' => :'String', :'notes' => :'String', :'status' => :'String', :'metadata' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/masspay_ruby_sdk/models/loads.rb', line 240 def ==(o) return true if self.equal?(o) self.class == o.class && load_token == o.load_token && time_of_load == o.time_of_load && client_load_id == o.client_load_id && source_token == o.source_token && wallet_token == o.wallet_token && amount == o.amount && source_currency_code == o.source_currency_code && notes == o.notes && status == o.status && == o. end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/masspay_ruby_sdk/models/loads.rb', line 301 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = MassPayRubySdk.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/masspay_ruby_sdk/models/loads.rb', line 372 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/masspay_ruby_sdk/models/loads.rb', line 277 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
257 258 259 |
# File 'lib/masspay_ruby_sdk/models/loads.rb', line 257 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
263 264 265 |
# File 'lib/masspay_ruby_sdk/models/loads.rb', line 263 def hash [load_token, time_of_load, client_load_id, source_token, wallet_token, amount, source_currency_code, notes, status, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/masspay_ruby_sdk/models/loads.rb', line 170 def list_invalid_properties invalid_properties = Array.new if @load_token.nil? invalid_properties.push('invalid value for "load_token", load_token cannot be nil.') end if @time_of_load.nil? invalid_properties.push('invalid value for "time_of_load", time_of_load cannot be nil.') end if @client_load_id.nil? invalid_properties.push('invalid value for "client_load_id", client_load_id cannot be nil.') end if @source_token.nil? invalid_properties.push('invalid value for "source_token", source_token cannot be nil.') end if @wallet_token.nil? invalid_properties.push('invalid value for "wallet_token", wallet_token cannot be nil.') end if @amount.nil? invalid_properties.push('invalid value for "amount", amount cannot be nil.') end if @source_currency_code.nil? invalid_properties.push('invalid value for "source_currency_code", source_currency_code cannot be nil.') end if @notes.nil? invalid_properties.push('invalid value for "notes", notes cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
348 349 350 |
# File 'lib/masspay_ruby_sdk/models/loads.rb', line 348 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/masspay_ruby_sdk/models/loads.rb', line 354 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
342 343 344 |
# File 'lib/masspay_ruby_sdk/models/loads.rb', line 342 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/masspay_ruby_sdk/models/loads.rb', line 213 def valid? return false if @load_token.nil? return false if @time_of_load.nil? return false if @client_load_id.nil? return false if @source_token.nil? return false if @wallet_token.nil? return false if @amount.nil? return false if @source_currency_code.nil? return false if @notes.nil? return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["COMPLETED", "CANCELLED", "SCHEDULED"]) return false unless status_validator.valid?(@status) true end |